# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/route/route_components.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type.matcher import regex_pb2 as envoy_dot_type_dot_matcher_dot_regex__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from envoy.type import range_pb2 as envoy_dot_type_dot_range__pb2
from envoy.type.tracing.v2 import custom_tag_pb2 as envoy_dot_type_dot_tracing_dot_v2_dot_custom__tag__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/api/v2/route/route_components.proto\x12\x12\x65nvoy.api.v2.route\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1e\x65nvoy/type/matcher/regex.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x16\x65nvoy/type/range.proto\x1a&envoy/type/tracing/v2/custom_tag.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa7\n\n\x0bVirtualHost\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12#\n\x07\x64omains\x18\x02 \x03(\tB\x12\xfa\x42\x0f\x92\x01\x0c\x08\x01\"\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12)\n\x06routes\x18\x03 \x03(\x0b\x32\x19.envoy.api.v2.route.Route\x12Q\n\x0brequire_tls\x18\x04 \x01(\x0e\x32\x32.envoy.api.v2.route.VirtualHost.TlsRequirementTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x10virtual_clusters\x18\x05 \x03(\x0b\x32\".envoy.api.v2.route.VirtualCluster\x12\x32\n\x0brate_limits\x18\x06 \x03(\x0b\x32\x1d.envoy.api.v2.route.RateLimit\x12O\n\x16request_headers_to_add\x18\x07 \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12!\n\x19request_headers_to_remove\x18\r \x03(\t\x12P\n\x17response_headers_to_add\x18\n \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\"\n\x1aresponse_headers_to_remove\x18\x0b \x03(\t\x12,\n\x04\x63ors\x18\x08 \x01(\x0b\x32\x1e.envoy.api.v2.route.CorsPolicy\x12S\n\x11per_filter_config\x18\x0c \x03(\x0b\x32\x34.envoy.api.v2.route.VirtualHost.PerFilterConfigEntryB\x02\x18\x01\x12Z\n\x17typed_per_filter_config\x18\x0f \x03(\x0b\x32\x39.envoy.api.v2.route.VirtualHost.TypedPerFilterConfigEntry\x12%\n\x1dinclude_request_attempt_count\x18\x0e \x01(\x08\x12)\n!include_attempt_count_in_response\x18\x13 \x01(\x08\x12\x35\n\x0cretry_policy\x18\x10 \x01(\x0b\x32\x1f.envoy.api.v2.route.RetryPolicy\x12\x37\n\x19retry_policy_typed_config\x18\x14 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x35\n\x0chedge_policy\x18\x11 \x01(\x0b\x32\x1f.envoy.api.v2.route.HedgePolicy\x12\x44\n\x1eper_request_buffer_limit_bytes\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1aO\n\x14PerFilterConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x1aQ\n\x19TypedPerFilterConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\":\n\x12TlsRequirementType\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rEXTERNAL_ONLY\x10\x01\x12\x07\n\x03\x41LL\x10\x02J\x04\x08\t\x10\n\"4\n\x0c\x46ilterAction\x12$\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"\xd5\x08\n\x05Route\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x37\n\x05match\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.route.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x30\n\x05route\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.route.RouteActionH\x00\x12\x36\n\x08redirect\x18\x03 \x01(\x0b\x32\".envoy.api.v2.route.RedirectActionH\x00\x12\x43\n\x0f\x64irect_response\x18\x07 \x01(\x0b\x32(.envoy.api.v2.route.DirectResponseActionH\x00\x12\x39\n\rfilter_action\x18\x11 \x01(\x0b\x32 .envoy.api.v2.route.FilterActionH\x00\x12-\n\x08metadata\x18\x04 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12\x30\n\tdecorator\x18\x05 \x01(\x0b\x32\x1d.envoy.api.v2.route.Decorator\x12M\n\x11per_filter_config\x18\x08 \x03(\x0b\x32..envoy.api.v2.route.Route.PerFilterConfigEntryB\x02\x18\x01\x12T\n\x17typed_per_filter_config\x18\r \x03(\x0b\x32\x33.envoy.api.v2.route.Route.TypedPerFilterConfigEntry\x12O\n\x16request_headers_to_add\x18\t \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12!\n\x19request_headers_to_remove\x18\x0c \x03(\t\x12P\n\x17response_headers_to_add\x18\n \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\"\n\x1aresponse_headers_to_remove\x18\x0b \x03(\t\x12,\n\x07tracing\x18\x0f \x01(\x0b\x32\x1b.envoy.api.v2.route.Tracing\x12\x44\n\x1eper_request_buffer_limit_bytes\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1aO\n\x14PerFilterConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x1aQ\n\x19TypedPerFilterConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x42\r\n\x06\x61\x63tion\x12\x03\xf8\x42\x01J\x04\x08\x06\x10\x07\"\xae\x07\n\x0fWeightedCluster\x12M\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x31.envoy.api.v2.route.WeightedCluster.ClusterWeightB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12;\n\x0ctotal_weight\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x1a\n\x12runtime_key_prefix\x18\x02 \x01(\t\x1a\xf2\x05\n\rClusterWeight\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12,\n\x06weight\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x33\n\x0emetadata_match\x18\x03 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12O\n\x16request_headers_to_add\x18\x04 \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12!\n\x19request_headers_to_remove\x18\t \x03(\t\x12P\n\x17response_headers_to_add\x18\x05 \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\"\n\x1aresponse_headers_to_remove\x18\x06 \x03(\t\x12\x65\n\x11per_filter_config\x18\x08 \x03(\x0b\x32\x46.envoy.api.v2.route.WeightedCluster.ClusterWeight.PerFilterConfigEntryB\x02\x18\x01\x12l\n\x17typed_per_filter_config\x18\n \x03(\x0b\x32K.envoy.api.v2.route.WeightedCluster.ClusterWeight.TypedPerFilterConfigEntry\x1aO\n\x14PerFilterConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x1aQ\n\x19TypedPerFilterConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01J\x04\x08\x07\x10\x08\"\xc5\x05\n\nRouteMatch\x12\x10\n\x06prefix\x18\x01 \x01(\tH\x00\x12\x0e\n\x04path\x18\x02 \x01(\tH\x00\x12!\n\x05regex\x18\x03 \x01(\tB\x10\x18\x01\xfa\x42\x05r\x03(\x80\x08\xb8\xee\xf2\xd2\x05\x01H\x00\x12@\n\nsafe_regex\x18\n \x01(\x0b\x32 .envoy.type.matcher.RegexMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x32\n\x0e\x63\x61se_sensitive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x45\n\x10runtime_fraction\x18\t \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12\x32\n\x07headers\x18\x06 \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcher\x12\x43\n\x10query_parameters\x18\x07 \x03(\x0b\x32).envoy.api.v2.route.QueryParameterMatcher\x12\x42\n\x04grpc\x18\x08 \x01(\x0b\x32\x34.envoy.api.v2.route.RouteMatch.GrpcRouteMatchOptions\x12J\n\x0btls_context\x18\x0b \x01(\x0b\x32\x35.envoy.api.v2.route.RouteMatch.TlsContextMatchOptions\x1a\x17\n\x15GrpcRouteMatchOptions\x1av\n\x16TlsContextMatchOptions\x12-\n\tpresented\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\tvalidated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x15\n\x0epath_specifier\x12\x03\xf8\x42\x01J\x04\x08\x05\x10\x06\"\x87\x04\n\nCorsPolicy\x12\x1e\n\x0c\x61llow_origin\x18\x01 \x03(\tB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12+\n\x12\x61llow_origin_regex\x18\x08 \x03(\tB\x0f\x18\x01\xfa\x42\n\x92\x01\x07\"\x05r\x03(\x80\x08\x12\x44\n\x19\x61llow_origin_string_match\x18\x0b \x03(\x0b\x32!.envoy.type.matcher.StringMatcher\x12\x15\n\rallow_methods\x18\x02 \x01(\t\x12\x15\n\rallow_headers\x18\x03 \x01(\t\x12\x16\n\x0e\x65xpose_headers\x18\x04 \x01(\t\x12\x0f\n\x07max_age\x18\x05 \x01(\t\x12\x35\n\x11\x61llow_credentials\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x07\x65nabled\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01H\x00\x12\x45\n\x0e\x66ilter_enabled\x18\t \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercentH\x00\x12\x43\n\x0eshadow_enabled\x18\n \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercentB\x13\n\x11\x65nabled_specifier\"\xf7\x16\n\x0bRouteAction\x12\x1a\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12\'\n\x0e\x63luster_header\x18\x02 \x01(\tB\r\xfa\x42\nr\x08 \x01\xc0\x01\x01\xc8\x01\x00H\x00\x12@\n\x11weighted_clusters\x18\x03 \x01(\x0b\x32#.envoy.api.v2.route.WeightedClusterH\x00\x12n\n\x1f\x63luster_not_found_response_code\x18\x14 \x01(\x0e\x32;.envoy.api.v2.route.RouteAction.ClusterNotFoundResponseCodeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x33\n\x0emetadata_match\x18\x04 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12#\n\x0eprefix_rewrite\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12\x42\n\rregex_rewrite\x18  \x01(\x0b\x32+.envoy.type.matcher.RegexMatchAndSubstitute\x12?\n\x0chost_rewrite\x18\x06 \x01(\tB\'\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\xf2\x98\xfe\x8f\x05\x16\n\x14host_rewrite_literalH\x01\x12\x37\n\x11\x61uto_host_rewrite\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x01\x12J\n\x18\x61uto_host_rewrite_header\x18\x1d \x01(\tB&\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\xf2\x98\xfe\x8f\x05\x15\n\x13host_rewrite_headerH\x01\x12*\n\x07timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0cidle_timeout\x18\x18 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x0cretry_policy\x18\t \x01(\x0b\x32\x1f.envoy.api.v2.route.RetryPolicy\x12\x37\n\x19retry_policy_typed_config\x18! \x01(\x0b\x32\x14.google.protobuf.Any\x12V\n\x15request_mirror_policy\x18\n \x01(\x0b\x32\x33.envoy.api.v2.route.RouteAction.RequestMirrorPolicyB\x02\x18\x01\x12T\n\x17request_mirror_policies\x18\x1e \x03(\x0b\x32\x33.envoy.api.v2.route.RouteAction.RequestMirrorPolicy\x12>\n\x08priority\x18\x0b \x01(\x0e\x32\".envoy.api.v2.core.RoutingPriorityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x32\n\x0brate_limits\x18\r \x03(\x0b\x32\x1d.envoy.api.v2.route.RateLimit\x12:\n\x16include_vh_rate_limits\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0bhash_policy\x18\x0f \x03(\x0b\x32*.envoy.api.v2.route.RouteAction.HashPolicy\x12,\n\x04\x63ors\x18\x11 \x01(\x0b\x32\x1e.envoy.api.v2.route.CorsPolicy\x12\x33\n\x10max_grpc_timeout\x18\x17 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x13grpc_timeout_offset\x18\x1c \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x46\n\x0fupgrade_configs\x18\x19 \x03(\x0b\x32-.envoy.api.v2.route.RouteAction.UpgradeConfig\x12X\n\x18internal_redirect_action\x18\x1a \x01(\x0e\x32\x36.envoy.api.v2.route.RouteAction.InternalRedirectAction\x12<\n\x16max_internal_redirects\x18\x1f \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x0chedge_policy\x18\x1b \x01(\x0b\x32\x1f.envoy.api.v2.route.HedgePolicy\x1a\xc8\x01\n\x13RequestMirrorPolicy\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1d\n\x0bruntime_key\x18\x02 \x01(\tB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x45\n\x10runtime_fraction\x18\x03 \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12\x31\n\rtrace_sampled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\xc7\x05\n\nHashPolicy\x12\x43\n\x06header\x18\x01 \x01(\x0b\x32\x31.envoy.api.v2.route.RouteAction.HashPolicy.HeaderH\x00\x12\x43\n\x06\x63ookie\x18\x02 \x01(\x0b\x32\x31.envoy.api.v2.route.RouteAction.HashPolicy.CookieH\x00\x12`\n\x15\x63onnection_properties\x18\x03 \x01(\x0b\x32?.envoy.api.v2.route.RouteAction.HashPolicy.ConnectionPropertiesH\x00\x12T\n\x0fquery_parameter\x18\x05 \x01(\x0b\x32\x39.envoy.api.v2.route.RouteAction.HashPolicy.QueryParameterH\x00\x12N\n\x0c\x66ilter_state\x18\x06 \x01(\x0b\x32\x36.envoy.api.v2.route.RouteAction.HashPolicy.FilterStateH\x00\x12\x10\n\x08terminal\x18\x04 \x01(\x08\x1a,\n\x06Header\x12\"\n\x0bheader_name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08 \x01\xc0\x01\x01\xc8\x01\x00\x1aU\n\x06\x43ookie\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12&\n\x03ttl\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04path\x18\x03 \x01(\t\x1a)\n\x14\x43onnectionProperties\x12\x11\n\tsource_ip\x18\x01 \x01(\x08\x1a\'\n\x0eQueryParameter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a#\n\x0b\x46ilterState\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x42\x17\n\x10policy_specifier\x12\x03\xf8\x42\x01\x1a_\n\rUpgradeConfig\x12!\n\x0cupgrade_type\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12+\n\x07\x65nabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"E\n\x1b\x43lusterNotFoundResponseCode\x12\x17\n\x13SERVICE_UNAVAILABLE\x10\x00\x12\r\n\tNOT_FOUND\x10\x01\"Z\n\x16InternalRedirectAction\x12\"\n\x1ePASS_THROUGH_INTERNAL_REDIRECT\x10\x00\x12\x1c\n\x18HANDLE_INTERNAL_REDIRECT\x10\x01\x42\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\x42\x18\n\x16host_rewrite_specifierJ\x04\x08\x0c\x10\rJ\x04\x08\x12\x10\x13J\x04\x08\x13\x10\x14J\x04\x08\x10\x10\x11J\x04\x08\x16\x10\x17J\x04\x08\x15\x10\x16\"\xed\x07\n\x0bRetryPolicy\x12\x10\n\x08retry_on\x18\x01 \x01(\t\x12\x31\n\x0bnum_retries\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x32\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x45\n\x0eretry_priority\x18\x04 \x01(\x0b\x32-.envoy.api.v2.route.RetryPolicy.RetryPriority\x12P\n\x14retry_host_predicate\x18\x05 \x03(\x0b\x32\x32.envoy.api.v2.route.RetryPolicy.RetryHostPredicate\x12)\n!host_selection_retry_max_attempts\x18\x06 \x01(\x03\x12\x1e\n\x16retriable_status_codes\x18\x07 \x03(\r\x12\x44\n\x0eretry_back_off\x18\x08 \x01(\x0b\x32,.envoy.api.v2.route.RetryPolicy.RetryBackOff\x12<\n\x11retriable_headers\x18\t \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcher\x12\x44\n\x19retriable_request_headers\x18\n \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcher\x1a\x92\x01\n\rRetryPriority\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\x1a\x97\x01\n\x12RetryHostPredicate\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\x1a\x87\x01\n\x0cRetryBackOff\x12<\n\rbase_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x39\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\"\xb2\x01\n\x0bHedgePolicy\x12?\n\x10initial_requests\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12@\n\x19\x61\x64\x64itional_request_chance\x18\x02 \x01(\x0b\x32\x1d.envoy.type.FractionalPercent\x12 \n\x18hedge_on_per_try_timeout\x18\x03 \x01(\x08\"\xeb\x03\n\x0eRedirectAction\x12\x18\n\x0ehttps_redirect\x18\x04 \x01(\x08H\x00\x12\x19\n\x0fscheme_redirect\x18\x07 \x01(\tH\x00\x12\"\n\rhost_redirect\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12\x15\n\rport_redirect\x18\x08 \x01(\r\x12$\n\rpath_redirect\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00H\x01\x12%\n\x0eprefix_rewrite\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00H\x01\x12X\n\rresponse_code\x18\x03 \x01(\x0e\x32\x37.envoy.api.v2.route.RedirectAction.RedirectResponseCodeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"w\n\x14RedirectResponseCode\x12\x15\n\x11MOVED_PERMANENTLY\x10\x00\x12\t\n\x05\x46OUND\x10\x01\x12\r\n\tSEE_OTHER\x10\x02\x12\x16\n\x12TEMPORARY_REDIRECT\x10\x03\x12\x16\n\x12PERMANENT_REDIRECT\x10\x04\x42\x1a\n\x18scheme_rewrite_specifierB\x18\n\x16path_rewrite_specifier\"_\n\x14\x44irectResponseAction\x12\x1a\n\x06status\x18\x01 \x01(\rB\n\xfa\x42\x07*\x05\x10\xd8\x04(d\x12+\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\"V\n\tDecorator\x12\x1a\n\toperation\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\tpropagate\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xe9\x01\n\x07Tracing\x12\x36\n\x0f\x63lient_sampling\x18\x01 \x01(\x0b\x32\x1d.envoy.type.FractionalPercent\x12\x36\n\x0frandom_sampling\x18\x02 \x01(\x0b\x32\x1d.envoy.type.FractionalPercent\x12\x37\n\x10overall_sampling\x18\x03 \x01(\x0b\x32\x1d.envoy.type.FractionalPercent\x12\x35\n\x0b\x63ustom_tags\x18\x04 \x03(\x0b\x32 .envoy.type.tracing.v2.CustomTag\"\xba\x01\n\x0eVirtualCluster\x12!\n\x07pattern\x18\x01 \x01(\tB\x10\x18\x01\xfa\x42\x05r\x03(\x80\x08\xb8\xee\xf2\xd2\x05\x01\x12\x32\n\x07headers\x18\x04 \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcher\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12:\n\x06method\x18\x03 \x01(\x0e\x32 .envoy.api.v2.core.RequestMethodB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\"\x84\x08\n\tRateLimit\x12\x34\n\x05stage\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\n\x12\x13\n\x0b\x64isable_key\x18\x02 \x01(\t\x12?\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32$.envoy.api.v2.route.RateLimit.ActionB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xea\x06\n\x06\x41\x63tion\x12L\n\x0esource_cluster\x18\x01 \x01(\x0b\x32\x32.envoy.api.v2.route.RateLimit.Action.SourceClusterH\x00\x12V\n\x13\x64\x65stination_cluster\x18\x02 \x01(\x0b\x32\x37.envoy.api.v2.route.RateLimit.Action.DestinationClusterH\x00\x12N\n\x0frequest_headers\x18\x03 \x01(\x0b\x32\x33.envoy.api.v2.route.RateLimit.Action.RequestHeadersH\x00\x12L\n\x0eremote_address\x18\x04 \x01(\x0b\x32\x32.envoy.api.v2.route.RateLimit.Action.RemoteAddressH\x00\x12\x46\n\x0bgeneric_key\x18\x05 \x01(\x0b\x32/.envoy.api.v2.route.RateLimit.Action.GenericKeyH\x00\x12S\n\x12header_value_match\x18\x06 \x01(\x0b\x32\x35.envoy.api.v2.route.RateLimit.Action.HeaderValueMatchH\x00\x1a\x0f\n\rSourceCluster\x1a\x14\n\x12\x44\x65stinationCluster\x1aU\n\x0eRequestHeaders\x12\"\n\x0bheader_name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08 \x01\xc0\x01\x01\xc8\x01\x00\x12\x1f\n\x0e\x64\x65scriptor_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a\x0f\n\rRemoteAddress\x1a/\n\nGenericKey\x12!\n\x10\x64\x65scriptor_value\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a\xa5\x01\n\x10HeaderValueMatch\x12!\n\x10\x64\x65scriptor_value\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x30\n\x0c\x65xpect_match\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x07headers\x18\x03 \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcherB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x17\n\x10\x61\x63tion_specifier\x12\x03\xf8\x42\x01\"\xf0\x02\n\rHeaderMatcher\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08 \x01\xc0\x01\x01\xc8\x01\x00\x12\x15\n\x0b\x65xact_match\x18\x04 \x01(\tH\x00\x12\'\n\x0bregex_match\x18\x05 \x01(\tB\x10\x18\x01\xfa\x42\x05r\x03(\x80\x08\xb8\xee\xf2\xd2\x05\x01H\x00\x12<\n\x10safe_regex_match\x18\x0b \x01(\x0b\x32 .envoy.type.matcher.RegexMatcherH\x00\x12-\n\x0brange_match\x18\x06 \x01(\x0b\x32\x16.envoy.type.Int64RangeH\x00\x12\x17\n\rpresent_match\x18\x07 \x01(\x08H\x00\x12\x1f\n\x0cprefix_match\x18\t \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12\x1f\n\x0csuffix_match\x18\n \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12\x14\n\x0cinvert_match\x18\x08 \x01(\x08\x42\x18\n\x16header_match_specifierJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"\x80\x02\n\x15QueryParameterMatcher\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05 \x01(\x80\x08\x12\x17\n\x05value\x18\x03 \x01(\tB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x33\n\x05regex\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x43\n\x0cstring_match\x18\x05 \x01(\x0b\x32!.envoy.type.matcher.StringMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x17\n\rpresent_match\x18\x06 \x01(\x08H\x00\x42!\n\x1fquery_parameter_match_specifierB\x9a\x01\n io.envoyproxy.envoy.api.v2.routeB\x14RouteComponentsProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2/route\xf2\x98\xfe\x8f\x05\x17\x12\x15\x65nvoy.config.route.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.route.route_components_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.envoyproxy.envoy.api.v2.routeB\024RouteComponentsProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2/route\362\230\376\217\005\027\022\025envoy.config.route.v3\272\200\310\321\006\002\020\001'
  _VIRTUALHOST_PERFILTERCONFIGENTRY._options = None
  _VIRTUALHOST_PERFILTERCONFIGENTRY._serialized_options = b'8\001'
  _VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY._options = None
  _VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY._serialized_options = b'8\001'
  _VIRTUALHOST.fields_by_name['name']._options = None
  _VIRTUALHOST.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _VIRTUALHOST.fields_by_name['domains']._options = None
  _VIRTUALHOST.fields_by_name['domains']._serialized_options = b'\372B\017\222\001\014\010\001\"\010r\006\300\001\002\310\001\000'
  _VIRTUALHOST.fields_by_name['require_tls']._options = None
  _VIRTUALHOST.fields_by_name['require_tls']._serialized_options = b'\372B\005\202\001\002\020\001'
  _VIRTUALHOST.fields_by_name['request_headers_to_add']._options = None
  _VIRTUALHOST.fields_by_name['request_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _VIRTUALHOST.fields_by_name['response_headers_to_add']._options = None
  _VIRTUALHOST.fields_by_name['response_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _VIRTUALHOST.fields_by_name['per_filter_config']._options = None
  _VIRTUALHOST.fields_by_name['per_filter_config']._serialized_options = b'\030\001'
  _ROUTE_PERFILTERCONFIGENTRY._options = None
  _ROUTE_PERFILTERCONFIGENTRY._serialized_options = b'8\001'
  _ROUTE_TYPEDPERFILTERCONFIGENTRY._options = None
  _ROUTE_TYPEDPERFILTERCONFIGENTRY._serialized_options = b'8\001'
  _ROUTE.oneofs_by_name['action']._options = None
  _ROUTE.oneofs_by_name['action']._serialized_options = b'\370B\001'
  _ROUTE.fields_by_name['match']._options = None
  _ROUTE.fields_by_name['match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE.fields_by_name['per_filter_config']._options = None
  _ROUTE.fields_by_name['per_filter_config']._serialized_options = b'\030\001'
  _ROUTE.fields_by_name['request_headers_to_add']._options = None
  _ROUTE.fields_by_name['request_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _ROUTE.fields_by_name['response_headers_to_add']._options = None
  _ROUTE.fields_by_name['response_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT_PERFILTERCONFIGENTRY._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT_PERFILTERCONFIGENTRY._serialized_options = b'8\001'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY._serialized_options = b'8\001'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['request_headers_to_add']._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['request_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['response_headers_to_add']._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['response_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['per_filter_config']._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['per_filter_config']._serialized_options = b'\030\001'
  _WEIGHTEDCLUSTER.fields_by_name['clusters']._options = None
  _WEIGHTEDCLUSTER.fields_by_name['clusters']._serialized_options = b'\372B\005\222\001\002\010\001'
  _WEIGHTEDCLUSTER.fields_by_name['total_weight']._options = None
  _WEIGHTEDCLUSTER.fields_by_name['total_weight']._serialized_options = b'\372B\004*\002(\001'
  _ROUTEMATCH.oneofs_by_name['path_specifier']._options = None
  _ROUTEMATCH.oneofs_by_name['path_specifier']._serialized_options = b'\370B\001'
  _ROUTEMATCH.fields_by_name['regex']._options = None
  _ROUTEMATCH.fields_by_name['regex']._serialized_options = b'\030\001\372B\005r\003(\200\010\270\356\362\322\005\001'
  _ROUTEMATCH.fields_by_name['safe_regex']._options = None
  _ROUTEMATCH.fields_by_name['safe_regex']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CORSPOLICY.fields_by_name['allow_origin']._options = None
  _CORSPOLICY.fields_by_name['allow_origin']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _CORSPOLICY.fields_by_name['allow_origin_regex']._options = None
  _CORSPOLICY.fields_by_name['allow_origin_regex']._serialized_options = b'\030\001\372B\n\222\001\007\"\005r\003(\200\010'
  _CORSPOLICY.fields_by_name['enabled']._options = None
  _CORSPOLICY.fields_by_name['enabled']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['cluster']._options = None
  _ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['cluster']._serialized_options = b'\372B\004r\002 \001'
  _ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['runtime_key']._options = None
  _ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['runtime_key']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _ROUTEACTION_HASHPOLICY_HEADER.fields_by_name['header_name']._options = None
  _ROUTEACTION_HASHPOLICY_HEADER.fields_by_name['header_name']._serialized_options = b'\372B\nr\010 \001\300\001\001\310\001\000'
  _ROUTEACTION_HASHPOLICY_COOKIE.fields_by_name['name']._options = None
  _ROUTEACTION_HASHPOLICY_COOKIE.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _ROUTEACTION_HASHPOLICY_QUERYPARAMETER.fields_by_name['name']._options = None
  _ROUTEACTION_HASHPOLICY_QUERYPARAMETER.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _ROUTEACTION_HASHPOLICY_FILTERSTATE.fields_by_name['key']._options = None
  _ROUTEACTION_HASHPOLICY_FILTERSTATE.fields_by_name['key']._serialized_options = b'\372B\004r\002 \001'
  _ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier']._options = None
  _ROUTEACTION_HASHPOLICY.oneofs_by_name['policy_specifier']._serialized_options = b'\370B\001'
  _ROUTEACTION_UPGRADECONFIG.fields_by_name['upgrade_type']._options = None
  _ROUTEACTION_UPGRADECONFIG.fields_by_name['upgrade_type']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._options = None
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._serialized_options = b'\370B\001'
  _ROUTEACTION.fields_by_name['cluster']._options = None
  _ROUTEACTION.fields_by_name['cluster']._serialized_options = b'\372B\004r\002 \001'
  _ROUTEACTION.fields_by_name['cluster_header']._options = None
  _ROUTEACTION.fields_by_name['cluster_header']._serialized_options = b'\372B\nr\010 \001\300\001\001\310\001\000'
  _ROUTEACTION.fields_by_name['cluster_not_found_response_code']._options = None
  _ROUTEACTION.fields_by_name['cluster_not_found_response_code']._serialized_options = b'\372B\005\202\001\002\020\001'
  _ROUTEACTION.fields_by_name['prefix_rewrite']._options = None
  _ROUTEACTION.fields_by_name['prefix_rewrite']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _ROUTEACTION.fields_by_name['host_rewrite']._options = None
  _ROUTEACTION.fields_by_name['host_rewrite']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000\362\230\376\217\005\026\n\024host_rewrite_literal'
  _ROUTEACTION.fields_by_name['auto_host_rewrite_header']._options = None
  _ROUTEACTION.fields_by_name['auto_host_rewrite_header']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000\362\230\376\217\005\025\n\023host_rewrite_header'
  _ROUTEACTION.fields_by_name['request_mirror_policy']._options = None
  _ROUTEACTION.fields_by_name['request_mirror_policy']._serialized_options = b'\030\001'
  _ROUTEACTION.fields_by_name['priority']._options = None
  _ROUTEACTION.fields_by_name['priority']._serialized_options = b'\372B\005\202\001\002\020\001'
  _RETRYPOLICY_RETRYPRIORITY.fields_by_name['name']._options = None
  _RETRYPOLICY_RETRYPRIORITY.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _RETRYPOLICY_RETRYPRIORITY.fields_by_name['config']._options = None
  _RETRYPOLICY_RETRYPRIORITY.fields_by_name['config']._serialized_options = b'\030\001'
  _RETRYPOLICY_RETRYHOSTPREDICATE.fields_by_name['name']._options = None
  _RETRYPOLICY_RETRYHOSTPREDICATE.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _RETRYPOLICY_RETRYHOSTPREDICATE.fields_by_name['config']._options = None
  _RETRYPOLICY_RETRYHOSTPREDICATE.fields_by_name['config']._serialized_options = b'\030\001'
  _RETRYPOLICY_RETRYBACKOFF.fields_by_name['base_interval']._options = None
  _RETRYPOLICY_RETRYBACKOFF.fields_by_name['base_interval']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _RETRYPOLICY_RETRYBACKOFF.fields_by_name['max_interval']._options = None
  _RETRYPOLICY_RETRYBACKOFF.fields_by_name['max_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEDGEPOLICY.fields_by_name['initial_requests']._options = None
  _HEDGEPOLICY.fields_by_name['initial_requests']._serialized_options = b'\372B\004*\002(\001'
  _REDIRECTACTION.fields_by_name['host_redirect']._options = None
  _REDIRECTACTION.fields_by_name['host_redirect']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _REDIRECTACTION.fields_by_name['path_redirect']._options = None
  _REDIRECTACTION.fields_by_name['path_redirect']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _REDIRECTACTION.fields_by_name['prefix_rewrite']._options = None
  _REDIRECTACTION.fields_by_name['prefix_rewrite']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _REDIRECTACTION.fields_by_name['response_code']._options = None
  _REDIRECTACTION.fields_by_name['response_code']._serialized_options = b'\372B\005\202\001\002\020\001'
  _DIRECTRESPONSEACTION.fields_by_name['status']._options = None
  _DIRECTRESPONSEACTION.fields_by_name['status']._serialized_options = b'\372B\007*\005\020\330\004(d'
  _DECORATOR.fields_by_name['operation']._options = None
  _DECORATOR.fields_by_name['operation']._serialized_options = b'\372B\004r\002 \001'
  _VIRTUALCLUSTER.fields_by_name['pattern']._options = None
  _VIRTUALCLUSTER.fields_by_name['pattern']._serialized_options = b'\030\001\372B\005r\003(\200\010\270\356\362\322\005\001'
  _VIRTUALCLUSTER.fields_by_name['name']._options = None
  _VIRTUALCLUSTER.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _VIRTUALCLUSTER.fields_by_name['method']._options = None
  _VIRTUALCLUSTER.fields_by_name['method']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _RATELIMIT_ACTION_REQUESTHEADERS.fields_by_name['header_name']._options = None
  _RATELIMIT_ACTION_REQUESTHEADERS.fields_by_name['header_name']._serialized_options = b'\372B\nr\010 \001\300\001\001\310\001\000'
  _RATELIMIT_ACTION_REQUESTHEADERS.fields_by_name['descriptor_key']._options = None
  _RATELIMIT_ACTION_REQUESTHEADERS.fields_by_name['descriptor_key']._serialized_options = b'\372B\004r\002 \001'
  _RATELIMIT_ACTION_GENERICKEY.fields_by_name['descriptor_value']._options = None
  _RATELIMIT_ACTION_GENERICKEY.fields_by_name['descriptor_value']._serialized_options = b'\372B\004r\002 \001'
  _RATELIMIT_ACTION_HEADERVALUEMATCH.fields_by_name['descriptor_value']._options = None
  _RATELIMIT_ACTION_HEADERVALUEMATCH.fields_by_name['descriptor_value']._serialized_options = b'\372B\004r\002 \001'
  _RATELIMIT_ACTION_HEADERVALUEMATCH.fields_by_name['headers']._options = None
  _RATELIMIT_ACTION_HEADERVALUEMATCH.fields_by_name['headers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _RATELIMIT_ACTION.oneofs_by_name['action_specifier']._options = None
  _RATELIMIT_ACTION.oneofs_by_name['action_specifier']._serialized_options = b'\370B\001'
  _RATELIMIT.fields_by_name['stage']._options = None
  _RATELIMIT.fields_by_name['stage']._serialized_options = b'\372B\004*\002\030\n'
  _RATELIMIT.fields_by_name['actions']._options = None
  _RATELIMIT.fields_by_name['actions']._serialized_options = b'\372B\005\222\001\002\010\001'
  _HEADERMATCHER.fields_by_name['name']._options = None
  _HEADERMATCHER.fields_by_name['name']._serialized_options = b'\372B\nr\010 \001\300\001\001\310\001\000'
  _HEADERMATCHER.fields_by_name['regex_match']._options = None
  _HEADERMATCHER.fields_by_name['regex_match']._serialized_options = b'\030\001\372B\005r\003(\200\010\270\356\362\322\005\001'
  _HEADERMATCHER.fields_by_name['prefix_match']._options = None
  _HEADERMATCHER.fields_by_name['prefix_match']._serialized_options = b'\372B\004r\002 \001'
  _HEADERMATCHER.fields_by_name['suffix_match']._options = None
  _HEADERMATCHER.fields_by_name['suffix_match']._serialized_options = b'\372B\004r\002 \001'
  _QUERYPARAMETERMATCHER.fields_by_name['name']._options = None
  _QUERYPARAMETERMATCHER.fields_by_name['name']._serialized_options = b'\372B\007r\005 \001(\200\010'
  _QUERYPARAMETERMATCHER.fields_by_name['value']._options = None
  _QUERYPARAMETERMATCHER.fields_by_name['value']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _QUERYPARAMETERMATCHER.fields_by_name['regex']._options = None
  _QUERYPARAMETERMATCHER.fields_by_name['regex']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _QUERYPARAMETERMATCHER.fields_by_name['string_match']._options = None
  _QUERYPARAMETERMATCHER.fields_by_name['string_match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_VIRTUALHOST']._serialized_start=497
  _globals['_VIRTUALHOST']._serialized_end=1816
  _globals['_VIRTUALHOST_PERFILTERCONFIGENTRY']._serialized_start=1588
  _globals['_VIRTUALHOST_PERFILTERCONFIGENTRY']._serialized_end=1667
  _globals['_VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY']._serialized_start=1669
  _globals['_VIRTUALHOST_TYPEDPERFILTERCONFIGENTRY']._serialized_end=1750
  _globals['_VIRTUALHOST_TLSREQUIREMENTTYPE']._serialized_start=1752
  _globals['_VIRTUALHOST_TLSREQUIREMENTTYPE']._serialized_end=1810
  _globals['_FILTERACTION']._serialized_start=1818
  _globals['_FILTERACTION']._serialized_end=1870
  _globals['_ROUTE']._serialized_start=1873
  _globals['_ROUTE']._serialized_end=2982
  _globals['_ROUTE_PERFILTERCONFIGENTRY']._serialized_start=1588
  _globals['_ROUTE_PERFILTERCONFIGENTRY']._serialized_end=1667
  _globals['_ROUTE_TYPEDPERFILTERCONFIGENTRY']._serialized_start=1669
  _globals['_ROUTE_TYPEDPERFILTERCONFIGENTRY']._serialized_end=1750
  _globals['_WEIGHTEDCLUSTER']._serialized_start=2985
  _globals['_WEIGHTEDCLUSTER']._serialized_end=3927
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT']._serialized_start=3173
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT']._serialized_end=3927
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT_PERFILTERCONFIGENTRY']._serialized_start=1588
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT_PERFILTERCONFIGENTRY']._serialized_end=1667
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY']._serialized_start=1669
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT_TYPEDPERFILTERCONFIGENTRY']._serialized_end=1750
  _globals['_ROUTEMATCH']._serialized_start=3930
  _globals['_ROUTEMATCH']._serialized_end=4639
  _globals['_ROUTEMATCH_GRPCROUTEMATCHOPTIONS']._serialized_start=4467
  _globals['_ROUTEMATCH_GRPCROUTEMATCHOPTIONS']._serialized_end=4490
  _globals['_ROUTEMATCH_TLSCONTEXTMATCHOPTIONS']._serialized_start=4492
  _globals['_ROUTEMATCH_TLSCONTEXTMATCHOPTIONS']._serialized_end=4610
  _globals['_CORSPOLICY']._serialized_start=4642
  _globals['_CORSPOLICY']._serialized_end=5161
  _globals['_ROUTEACTION']._serialized_start=5164
  _globals['_ROUTEACTION']._serialized_end=8099
  _globals['_ROUTEACTION_REQUESTMIRRORPOLICY']._serialized_start=6837
  _globals['_ROUTEACTION_REQUESTMIRRORPOLICY']._serialized_end=7037
  _globals['_ROUTEACTION_HASHPOLICY']._serialized_start=7040
  _globals['_ROUTEACTION_HASHPOLICY']._serialized_end=7751
  _globals['_ROUTEACTION_HASHPOLICY_HEADER']._serialized_start=7474
  _globals['_ROUTEACTION_HASHPOLICY_HEADER']._serialized_end=7518
  _globals['_ROUTEACTION_HASHPOLICY_COOKIE']._serialized_start=7520
  _globals['_ROUTEACTION_HASHPOLICY_COOKIE']._serialized_end=7605
  _globals['_ROUTEACTION_HASHPOLICY_CONNECTIONPROPERTIES']._serialized_start=7607
  _globals['_ROUTEACTION_HASHPOLICY_CONNECTIONPROPERTIES']._serialized_end=7648
  _globals['_ROUTEACTION_HASHPOLICY_QUERYPARAMETER']._serialized_start=7650
  _globals['_ROUTEACTION_HASHPOLICY_QUERYPARAMETER']._serialized_end=7689
  _globals['_ROUTEACTION_HASHPOLICY_FILTERSTATE']._serialized_start=7691
  _globals['_ROUTEACTION_HASHPOLICY_FILTERSTATE']._serialized_end=7726
  _globals['_ROUTEACTION_UPGRADECONFIG']._serialized_start=7753
  _globals['_ROUTEACTION_UPGRADECONFIG']._serialized_end=7848
  _globals['_ROUTEACTION_CLUSTERNOTFOUNDRESPONSECODE']._serialized_start=7850
  _globals['_ROUTEACTION_CLUSTERNOTFOUNDRESPONSECODE']._serialized_end=7919
  _globals['_ROUTEACTION_INTERNALREDIRECTACTION']._serialized_start=7921
  _globals['_ROUTEACTION_INTERNALREDIRECTACTION']._serialized_end=8011
  _globals['_RETRYPOLICY']._serialized_start=8102
  _globals['_RETRYPOLICY']._serialized_end=9107
  _globals['_RETRYPOLICY_RETRYPRIORITY']._serialized_start=8669
  _globals['_RETRYPOLICY_RETRYPRIORITY']._serialized_end=8815
  _globals['_RETRYPOLICY_RETRYHOSTPREDICATE']._serialized_start=8818
  _globals['_RETRYPOLICY_RETRYHOSTPREDICATE']._serialized_end=8969
  _globals['_RETRYPOLICY_RETRYBACKOFF']._serialized_start=8972
  _globals['_RETRYPOLICY_RETRYBACKOFF']._serialized_end=9107
  _globals['_HEDGEPOLICY']._serialized_start=9110
  _globals['_HEDGEPOLICY']._serialized_end=9288
  _globals['_REDIRECTACTION']._serialized_start=9291
  _globals['_REDIRECTACTION']._serialized_end=9782
  _globals['_REDIRECTACTION_REDIRECTRESPONSECODE']._serialized_start=9609
  _globals['_REDIRECTACTION_REDIRECTRESPONSECODE']._serialized_end=9728
  _globals['_DIRECTRESPONSEACTION']._serialized_start=9784
  _globals['_DIRECTRESPONSEACTION']._serialized_end=9879
  _globals['_DECORATOR']._serialized_start=9881
  _globals['_DECORATOR']._serialized_end=9967
  _globals['_TRACING']._serialized_start=9970
  _globals['_TRACING']._serialized_end=10203
  _globals['_VIRTUALCLUSTER']._serialized_start=10206
  _globals['_VIRTUALCLUSTER']._serialized_end=10392
  _globals['_RATELIMIT']._serialized_start=10395
  _globals['_RATELIMIT']._serialized_end=11423
  _globals['_RATELIMIT_ACTION']._serialized_start=10549
  _globals['_RATELIMIT_ACTION']._serialized_end=11423
  _globals['_RATELIMIT_ACTION_SOURCECLUSTER']._serialized_start=11040
  _globals['_RATELIMIT_ACTION_SOURCECLUSTER']._serialized_end=11055
  _globals['_RATELIMIT_ACTION_DESTINATIONCLUSTER']._serialized_start=11057
  _globals['_RATELIMIT_ACTION_DESTINATIONCLUSTER']._serialized_end=11077
  _globals['_RATELIMIT_ACTION_REQUESTHEADERS']._serialized_start=11079
  _globals['_RATELIMIT_ACTION_REQUESTHEADERS']._serialized_end=11164
  _globals['_RATELIMIT_ACTION_REMOTEADDRESS']._serialized_start=11166
  _globals['_RATELIMIT_ACTION_REMOTEADDRESS']._serialized_end=11181
  _globals['_RATELIMIT_ACTION_GENERICKEY']._serialized_start=11183
  _globals['_RATELIMIT_ACTION_GENERICKEY']._serialized_end=11230
  _globals['_RATELIMIT_ACTION_HEADERVALUEMATCH']._serialized_start=11233
  _globals['_RATELIMIT_ACTION_HEADERVALUEMATCH']._serialized_end=11398
  _globals['_HEADERMATCHER']._serialized_start=11426
  _globals['_HEADERMATCHER']._serialized_end=11794
  _globals['_QUERYPARAMETERMATCHER']._serialized_start=11797
  _globals['_QUERYPARAMETERMATCHER']._serialized_end=12053
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/generic_proxy/v3/generic_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.extensions.filters.network.generic_proxy.v3 import route_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_generic__proxy_dot_v3_dot_route__pb2
from envoy.extensions.filters.network.http_connection_manager.v3 import http_connection_manager_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_http__connection__manager_dot_v3_dot_http__connection__manager__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEenvoy/extensions/filters/network/generic_proxy/v3/generic_proxy.proto\x12\x31\x65nvoy.extensions.filters.network.generic_proxy.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1a(envoy/config/core/v3/config_source.proto\x1a$envoy/config/core/v3/extension.proto\x1a=envoy/extensions/filters/network/generic_proxy/v3/route.proto\x1aYenvoy/extensions/filters/network/http_connection_manager/v3/http_connection_manager.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa9\x04\n\x0cGenericProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12J\n\x0c\x63odec_config\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12T\n\x0bgeneric_rds\x18\x03 \x01(\x0b\x32=.envoy.extensions.filters.network.generic_proxy.v3.GenericRdsH\x00\x12]\n\x0croute_config\x18\x04 \x01(\x0b\x32\x45.envoy.extensions.filters.network.generic_proxy.v3.RouteConfigurationH\x00\x12;\n\x07\x66ilters\x18\x05 \x03(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12k\n\x07tracing\x18\x06 \x01(\x0b\x32Z.envoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.Tracing\x12\x38\n\naccess_log\x18\x07 \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLogB\x16\n\x0froute_specifier\x12\x03\xf8\x42\x01\"u\n\nGenericRds\x12\x43\n\rconfig_source\x18\x01 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\"\n\x11route_config_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\xd0\x01\n?io.envoyproxy.envoy.extensions.filters.network.generic_proxy.v3B\x11GenericProxyProtoP\x01Zhgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/generic_proxy/v3;generic_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.generic_proxy.v3.generic_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.extensions.filters.network.generic_proxy.v3B\021GenericProxyProtoP\001Zhgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/generic_proxy/v3;generic_proxyv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _GENERICPROXY.oneofs_by_name['route_specifier']._options = None
  _GENERICPROXY.oneofs_by_name['route_specifier']._serialized_options = b'\370B\001'
  _GENERICPROXY.fields_by_name['stat_prefix']._options = None
  _GENERICPROXY.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _GENERICPROXY.fields_by_name['codec_config']._options = None
  _GENERICPROXY.fields_by_name['codec_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GENERICRDS.fields_by_name['config_source']._options = None
  _GENERICRDS.fields_by_name['config_source']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GENERICRDS.fields_by_name['route_config_name']._options = None
  _GENERICRDS.fields_by_name['route_config_name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GENERICPROXY']._serialized_start=491
  _globals['_GENERICPROXY']._serialized_end=1044
  _globals['_GENERICRDS']._serialized_start=1046
  _globals['_GENERICRDS']._serialized_end=1163
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/common/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*opentelemetry/proto/common/v1/common.proto\x12\x1dopentelemetry.proto.common.v1\"\x8c\x02\n\x08\x41nyValue\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12@\n\x0b\x61rray_value\x18\x05 \x01(\x0b\x32).opentelemetry.proto.common.v1.ArrayValueH\x00\x12\x43\n\x0ckvlist_value\x18\x06 \x01(\x0b\x32+.opentelemetry.proto.common.v1.KeyValueListH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x42\x07\n\x05value\"E\n\nArrayValue\x12\x37\n\x06values\x18\x01 \x03(\x0b\x32\'.opentelemetry.proto.common.v1.AnyValue\"G\n\x0cKeyValueList\x12\x37\n\x06values\x18\x01 \x03(\x0b\x32\'.opentelemetry.proto.common.v1.KeyValue\"O\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.opentelemetry.proto.common.v1.AnyValue\"0\n\x0eStringKeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x18\x01\"7\n\x16InstrumentationLibrary\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\tBq\n io.opentelemetry.proto.common.v1B\x0b\x43ommonProtoP\x01Z>github.com/open-telemetry/opentelemetry-proto/gen/go/common/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opentelemetry.proto.common.v1.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.opentelemetry.proto.common.v1B\013CommonProtoP\001Z>github.com/open-telemetry/opentelemetry-proto/gen/go/common/v1'
  _STRINGKEYVALUE._options = None
  _STRINGKEYVALUE._serialized_options = b'\030\001'
  _globals['_ANYVALUE']._serialized_start=78
  _globals['_ANYVALUE']._serialized_end=346
  _globals['_ARRAYVALUE']._serialized_start=348
  _globals['_ARRAYVALUE']._serialized_end=417
  _globals['_KEYVALUELIST']._serialized_start=419
  _globals['_KEYVALUELIST']._serialized_end=490
  _globals['_KEYVALUE']._serialized_start=492
  _globals['_KEYVALUE']._serialized_end=571
  _globals['_STRINGKEYVALUE']._serialized_start=573
  _globals['_STRINGKEYVALUE']._serialized_end=621
  _globals['_INSTRUMENTATIONLIBRARY']._serialized_start=623
  _globals['_INSTRUMENTATIONLIBRARY']._serialized_end=678
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher import number_pb2 as envoy_dot_type_dot_matcher_dot_number__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/type/matcher/value.proto\x12\x12\x65nvoy.type.matcher\x1a\x1f\x65nvoy/type/matcher/number.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcf\x02\n\x0cValueMatcher\x12@\n\nnull_match\x18\x01 \x01(\x0b\x32*.envoy.type.matcher.ValueMatcher.NullMatchH\x00\x12\x39\n\x0c\x64ouble_match\x18\x02 \x01(\x0b\x32!.envoy.type.matcher.DoubleMatcherH\x00\x12\x39\n\x0cstring_match\x18\x03 \x01(\x0b\x32!.envoy.type.matcher.StringMatcherH\x00\x12\x14\n\nbool_match\x18\x04 \x01(\x08H\x00\x12\x17\n\rpresent_match\x18\x05 \x01(\x08H\x00\x12\x35\n\nlist_match\x18\x06 \x01(\x0b\x32\x1f.envoy.type.matcher.ListMatcherH\x00\x1a\x0b\n\tNullMatchB\x14\n\rmatch_pattern\x12\x03\xf8\x42\x01\"W\n\x0bListMatcher\x12\x32\n\x06one_of\x18\x01 \x01(\x0b\x32 .envoy.type.matcher.ValueMatcherH\x00\x42\x14\n\rmatch_pattern\x12\x03\xf8\x42\x01\x42s\n io.envoyproxy.envoy.type.matcherB\nValueProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.value_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.envoyproxy.envoy.type.matcherB\nValueProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\272\200\310\321\006\002\020\001'
  _VALUEMATCHER.oneofs_by_name['match_pattern']._options = None
  _VALUEMATCHER.oneofs_by_name['match_pattern']._serialized_options = b'\370B\001'
  _LISTMATCHER.oneofs_by_name['match_pattern']._options = None
  _LISTMATCHER.oneofs_by_name['match_pattern']._serialized_options = b'\370B\001'
  _globals['_VALUEMATCHER']._serialized_start=177
  _globals['_VALUEMATCHER']._serialized_end=512
  _globals['_VALUEMATCHER_NULLMATCH']._serialized_start=479
  _globals['_VALUEMATCHER_NULLMATCH']._serialized_end=490
  _globals['_LISTMATCHER']._serialized_start=514
  _globals['_LISTMATCHER']._serialized_end=601
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_stats/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_method_list_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__method__list__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/extensions/filters/http/grpc_stats/v3/config.proto\x12+envoy.extensions.filters.http.grpc_stats.v3\x1a+envoy/config/core/v3/grpc_method_list.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xe1\x02\n\x0c\x46ilterConfig\x12\x19\n\x11\x65mit_filter_state\x18\x01 \x01(\x08\x12Q\n!individual_method_stats_allowlist\x18\x02 \x01(\x0b\x32$.envoy.config.core.v3.GrpcMethodListH\x00\x12;\n\x15stats_for_all_methods\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x12\x1d\n\x15\x65nable_upstream_stats\x18\x04 \x01(\x08\x12)\n!replace_dots_in_grpc_service_name\x18\x05 \x01(\x08:?\x9a\xc5\x88\x1e:\n8envoy.config.filter.http.grpc_stats.v2alpha.FilterConfigB\x1b\n\x19per_method_stat_specifier\"\x8e\x01\n\x0c\x46ilterObject\x12\x1d\n\x15request_message_count\x18\x01 \x01(\x04\x12\x1e\n\x16response_message_count\x18\x02 \x01(\x04:?\x9a\xc5\x88\x1e:\n8envoy.config.filter.http.grpc_stats.v2alpha.FilterObjectB\xb3\x01\n9io.envoyproxy.envoy.extensions.filters.http.grpc_stats.v3B\x0b\x43onfigProtoP\x01Z_github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_stats/v3;grpc_statsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.grpc_stats.v3.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n9io.envoyproxy.envoy.extensions.filters.http.grpc_stats.v3B\013ConfigProtoP\001Z_github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_stats/v3;grpc_statsv3\272\200\310\321\006\002\020\002'
  _FILTERCONFIG._options = None
  _FILTERCONFIG._serialized_options = b'\232\305\210\036:\n8envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig'
  _FILTEROBJECT._options = None
  _FILTEROBJECT._serialized_options = b'\232\305\210\036:\n8envoy.config.filter.http.grpc_stats.v2alpha.FilterObject'
  _globals['_FILTERCONFIG']._serialized_start=249
  _globals['_FILTERCONFIG']._serialized_end=602
  _globals['_FILTEROBJECT']._serialized_start=605
  _globals['_FILTEROBJECT']._serialized_end=747
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.extensions.filters.network.thrift_proxy.v3 import route_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_thrift__proxy_dot_v3_dot_route__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCenvoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto\x12\x30\x65nvoy.extensions.filters.network.thrift_proxy.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1a(envoy/config/core/v3/config_source.proto\x1a<envoy/extensions/filters/network/thrift_proxy/v3/route.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"f\n\x04Trds\x12\x43\n\rconfig_source\x18\x01 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x11route_config_name\x18\x02 \x01(\t\"\x94\x06\n\x0bThriftProxy\x12\\\n\ttransport\x18\x02 \x01(\x0e\x32?.envoy.extensions.filters.network.thrift_proxy.v3.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x08protocol\x18\x03 \x01(\x0e\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12s\n\x0croute_config\x18\x04 \x01(\x0b\x32\x44.envoy.extensions.filters.network.thrift_proxy.v3.RouteConfigurationB\x17\xf2\x98\xfe\x8f\x05\x11\x12\x0froute_specifier\x12]\n\x04trds\x18\x08 \x01(\x0b\x32\x36.envoy.extensions.filters.network.thrift_proxy.v3.TrdsB\x17\xf2\x98\xfe\x8f\x05\x11\x12\x0froute_specifier\x12V\n\x0ethrift_filters\x18\x05 \x03(\x0b\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter\x12\x1b\n\x13payload_passthrough\x18\x06 \x01(\x08\x12\x41\n\x1bmax_requests_per_connection\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x38\n\naccess_log\x18\t \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12!\n\x19header_keys_preserve_case\x18\n \x01(\x08:D\x9a\xc5\x88\x1e?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProxy\"\xb7\x01\n\x0cThriftFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:E\x9a\xc5\x88\x1e@\n>envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"\xa1\x02\n\x15ThriftProtocolOptions\x12\\\n\ttransport\x18\x01 \x01(\x0e\x32?.envoy.extensions.filters.network.thrift_proxy.v3.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x08protocol\x18\x02 \x01(\x0e\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:N\x9a\xc5\x88\x1eI\nGenvoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProtocolOptions*I\n\rTransportType\x12\x12\n\x0e\x41UTO_TRANSPORT\x10\x00\x12\n\n\x06\x46RAMED\x10\x01\x12\x0c\n\x08UNFRAMED\x10\x02\x12\n\n\x06HEADER\x10\x03*d\n\x0cProtocolType\x12\x11\n\rAUTO_PROTOCOL\x10\x00\x12\n\n\x06\x42INARY\x10\x01\x12\x0e\n\nLAX_BINARY\x10\x02\x12\x0b\n\x07\x43OMPACT\x10\x03\x12\x18\n\x07TWITTER\x10\x04\x1a\x0b\x08\x01\x8a\xf4\x9b\xb3\x05\x03\x33.0B\xc4\x01\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\x10ThriftProxyProtoP\x01Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/v3;thrift_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.thrift_proxy.v3.thrift_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\020ThriftProxyProtoP\001Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/v3;thrift_proxyv3\272\200\310\321\006\002\020\002'
  _PROTOCOLTYPE.values_by_name["TWITTER"]._options = None
  _PROTOCOLTYPE.values_by_name["TWITTER"]._serialized_options = b'\010\001\212\364\233\263\005\0033.0'
  _TRDS.fields_by_name['config_source']._options = None
  _TRDS.fields_by_name['config_source']._serialized_options = b'\372B\005\212\001\002\020\001'
  _THRIFTPROXY.fields_by_name['transport']._options = None
  _THRIFTPROXY.fields_by_name['transport']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROXY.fields_by_name['protocol']._options = None
  _THRIFTPROXY.fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROXY.fields_by_name['stat_prefix']._options = None
  _THRIFTPROXY.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _THRIFTPROXY.fields_by_name['route_config']._options = None
  _THRIFTPROXY.fields_by_name['route_config']._serialized_options = b'\362\230\376\217\005\021\022\017route_specifier'
  _THRIFTPROXY.fields_by_name['trds']._options = None
  _THRIFTPROXY.fields_by_name['trds']._serialized_options = b'\362\230\376\217\005\021\022\017route_specifier'
  _THRIFTPROXY._options = None
  _THRIFTPROXY._serialized_options = b'\232\305\210\036?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProxy'
  _THRIFTFILTER.fields_by_name['name']._options = None
  _THRIFTFILTER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _THRIFTFILTER._options = None
  _THRIFTFILTER._serialized_options = b'\232\305\210\036@\n>envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftFilter'
  _THRIFTPROTOCOLOPTIONS.fields_by_name['transport']._options = None
  _THRIFTPROTOCOLOPTIONS.fields_by_name['transport']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROTOCOLOPTIONS.fields_by_name['protocol']._options = None
  _THRIFTPROTOCOLOPTIONS.fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROTOCOLOPTIONS._options = None
  _THRIFTPROTOCOLOPTIONS._serialized_options = b'\232\305\210\036I\nGenvoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProtocolOptions'
  _globals['_TRANSPORTTYPE']._serialized_start=1860
  _globals['_TRANSPORTTYPE']._serialized_end=1933
  _globals['_PROTOCOLTYPE']._serialized_start=1935
  _globals['_PROTOCOLTYPE']._serialized_end=2035
  _globals['_TRDS']._serialized_start=487
  _globals['_TRDS']._serialized_end=589
  _globals['_THRIFTPROXY']._serialized_start=592
  _globals['_THRIFTPROXY']._serialized_end=1380
  _globals['_THRIFTFILTER']._serialized_start=1383
  _globals['_THRIFTFILTER']._serialized_end=1566
  _globals['_THRIFTPROTOCOLOPTIONS']._serialized_start=1569
  _globals['_THRIFTPROTOCOLOPTIONS']._serialized_end=1858
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/http/header_formatters/preserve_case/v3/preserve_case.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLenvoy/extensions/http/header_formatters/preserve_case/v3/preserve_case.proto\x12\x38\x65nvoy.extensions.http.header_formatters.preserve_case.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa0\x02\n\x1bPreserveCaseFormatterConfig\x12\x1d\n\x15\x66orward_reason_phrase\x18\x01 \x01(\x08\x12\xa4\x01\n\x1f\x66ormatter_type_on_envoy_headers\x18\x02 \x01(\x0e\x32q.envoy.extensions.http.header_formatters.preserve_case.v3.PreserveCaseFormatterConfig.FormatterTypeOnEnvoyHeadersB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\";\n\x1b\x46ormatterTypeOnEnvoyHeaders\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0f\n\x0bPROPER_CASE\x10\x01\x42\xd6\x01\nFio.envoyproxy.envoy.extensions.http.header_formatters.preserve_case.v3B\x11PreserveCaseProtoP\x01Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/http/header_formatters/preserve_case/v3;preserve_casev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.header_formatters.preserve_case.v3.preserve_case_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nFio.envoyproxy.envoy.extensions.http.header_formatters.preserve_case.v3B\021PreserveCaseProtoP\001Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/http/header_formatters/preserve_case/v3;preserve_casev3\272\200\310\321\006\002\020\002'
  _PRESERVECASEFORMATTERCONFIG.fields_by_name['formatter_type_on_envoy_headers']._options = None
  _PRESERVECASEFORMATTERCONFIG.fields_by_name['formatter_type_on_envoy_headers']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PRESERVECASEFORMATTERCONFIG']._serialized_start=195
  _globals['_PRESERVECASEFORMATTERCONFIG']._serialized_end=483
  _globals['_PRESERVECASEFORMATTERCONFIG_FORMATTERTYPEONENVOYHEADERS']._serialized_start=424
  _globals['_PRESERVECASEFORMATTERCONFIG_FORMATTERTYPEONENVOYHEADERS']._serialized_end=483
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/core/v3/authority.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bxds/core/v3/authority.proto\x12\x0bxds.core.v3\x1a\x1fxds/annotations/v3/status.proto\x1a\x17validate/validate.proto\"\"\n\tAuthority\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42V\n\x16\x63om.github.xds.core.v3B\x0e\x41uthorityProtoP\x01Z\"github.com/cncf/xds/go/xds/core/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.core.v3.authority_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.github.xds.core.v3B\016AuthorityProtoP\001Z\"github.com/cncf/xds/go/xds/core/v3\322\306\244\341\006\002\010\001'
  _AUTHORITY.fields_by_name['name']._options = None
  _AUTHORITY.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_AUTHORITY']._serialized_start=102
  _globals['_AUTHORITY']._serialized_end=136
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google/api/policy.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto\"S\n\x0b\x46ieldPolicy\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x1b\n\x13resource_permission\x18\x02 \x01(\t\x12\x15\n\rresource_type\x18\x03 \x01(\t\"S\n\x0cMethodPolicy\x12\x10\n\x08selector\x18\t \x01(\t\x12\x31\n\x10request_policies\x18\x02 \x03(\x0b\x32\x17.google.api.FieldPolicy:O\n\x0c\x66ield_policy\x12\x1d.google.protobuf.FieldOptions\x18\xe8\xce\xc1K \x01(\x0b\x32\x17.google.api.FieldPolicy:R\n\rmethod_policy\x12\x1e.google.protobuf.MethodOptions\x18\xb5\x97\x99M \x01(\x0b\x32\x18.google.api.MethodPolicyBp\n\x0e\x63om.google.apiB\x0bPolicyProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xf8\x01\x01\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.policy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\013PolicyProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\370\001\001\242\002\004GAPI'
  _globals['_FIELDPOLICY']._serialized_start=73
  _globals['_FIELDPOLICY']._serialized_end=156
  _globals['_METHODPOLICY']._serialized_start=158
  _globals['_METHODPOLICY']._serialized_end=241
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/grpc_credential/v3/file_based_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9envoy/config/grpc_credential/v3/file_based_metadata.proto\x12\x1f\x65nvoy.config.grpc_credential.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xc8\x01\n\x17\x46ileBasedMetadataConfig\x12=\n\x0bsecret_data\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x12\n\nheader_key\x18\x02 \x01(\t\x12\x15\n\rheader_prefix\x18\x03 \x01(\t:C\x9a\xc5\x88\x1e>\n<envoy.config.grpc_credential.v2alpha.FileBasedMetadataConfigB\xab\x01\n-io.envoyproxy.envoy.config.grpc_credential.v3B\x16\x46ileBasedMetadataProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/config/grpc_credential/v3;grpc_credentialv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.grpc_credential.v3.file_based_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-io.envoyproxy.envoy.config.grpc_credential.v3B\026FileBasedMetadataProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/config/grpc_credential/v3;grpc_credentialv3\272\200\310\321\006\002\020\002'
  _FILEBASEDMETADATACONFIG.fields_by_name['secret_data']._options = None
  _FILEBASEDMETADATACONFIG.fields_by_name['secret_data']._serialized_options = b'\270\267\213\244\002\001'
  _FILEBASEDMETADATACONFIG._options = None
  _FILEBASEDMETADATACONFIG._serialized_options = b'\232\305\210\036>\n<envoy.config.grpc_credential.v2alpha.FileBasedMetadataConfig'
  _globals['_FILEBASEDMETADATACONFIG']._serialized_start=228
  _globals['_FILEBASEDMETADATACONFIG']._serialized_end=428
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/tap/v3/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.tap.v3 import common_pb2 as envoy_dot_config_dot_tap_dot_v3_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+envoy/extensions/common/tap/v3/common.proto\x12\x1e\x65nvoy.extensions.common.tap.v3\x1a envoy/config/tap/v3/common.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe7\x01\n\x15\x43ommonExtensionConfig\x12\x43\n\x0c\x61\x64min_config\x18\x01 \x01(\x0b\x32+.envoy.extensions.common.tap.v3.AdminConfigH\x00\x12\x37\n\rstatic_config\x18\x02 \x01(\x0b\x32\x1e.envoy.config.tap.v3.TapConfigH\x00:<\x9a\xc5\x88\x1e\x37\n5envoy.config.common.tap.v2alpha.CommonExtensionConfigB\x12\n\x0b\x63onfig_type\x12\x03\xf8\x42\x01\"]\n\x0b\x41\x64minConfig\x12\x1a\n\tconfig_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:2\x9a\xc5\x88\x1e-\n+envoy.config.common.tap.v2alpha.AdminConfigB\x92\x01\n,io.envoyproxy.envoy.extensions.common.tap.v3B\x0b\x43ommonProtoP\x01ZKgithub.com/envoyproxy/go-control-plane/envoy/extensions/common/tap/v3;tapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.common.tap.v3.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,io.envoyproxy.envoy.extensions.common.tap.v3B\013CommonProtoP\001ZKgithub.com/envoyproxy/go-control-plane/envoy/extensions/common/tap/v3;tapv3\272\200\310\321\006\002\020\002'
  _COMMONEXTENSIONCONFIG.oneofs_by_name['config_type']._options = None
  _COMMONEXTENSIONCONFIG.oneofs_by_name['config_type']._serialized_options = b'\370B\001'
  _COMMONEXTENSIONCONFIG._options = None
  _COMMONEXTENSIONCONFIG._serialized_options = b'\232\305\210\0367\n5envoy.config.common.tap.v2alpha.CommonExtensionConfig'
  _ADMINCONFIG.fields_by_name['config_id']._options = None
  _ADMINCONFIG.fields_by_name['config_id']._serialized_options = b'\372B\004r\002\020\001'
  _ADMINCONFIG._options = None
  _ADMINCONFIG._serialized_options = b'\232\305\210\036-\n+envoy.config.common.tap.v2alpha.AdminConfig'
  _globals['_COMMONEXTENSIONCONFIG']._serialized_start=205
  _globals['_COMMONEXTENSIONCONFIG']._serialized_end=436
  _globals['_ADMINCONFIG']._serialized_start=438
  _globals['_ADMINCONFIG']._serialized_end=531
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/color.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google/type/color.proto\x12\x0bgoogle.type\x1a\x1egoogle/protobuf/wrappers.proto\"]\n\x05\x43olor\x12\x0b\n\x03red\x18\x01 \x01(\x02\x12\r\n\x05green\x18\x02 \x01(\x02\x12\x0c\n\x04\x62lue\x18\x03 \x01(\x02\x12*\n\x05\x61lpha\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueB`\n\x0f\x63om.google.typeB\nColorProtoP\x01Z6google.golang.org/genproto/googleapis/type/color;color\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.color_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017com.google.typeB\nColorProtoP\001Z6google.golang.org/genproto/googleapis/type/color;color\370\001\001\242\002\003GTP'
  _globals['_COLOR']._serialized_start=72
  _globals['_COLOR']._serialized_end=165
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/rate_limit_quota/v3/rate_limit_quota.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from envoy.type.v3 import ratelimit_strategy_pb2 as envoy_dot_type_dot_v3_dot_ratelimit__strategy__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/extensions/filters/http/rate_limit_quota/v3/rate_limit_quota.proto\x12\x31\x65nvoy.extensions.filters.http.rate_limit_quota.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a&envoy/type/v3/ratelimit_strategy.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\x1a\x1fxds/annotations/v3/status.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xae\x03\n\x1aRateLimitQuotaFilterConfig\x12@\n\x0brlqs_server\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x17\n\x06\x64omain\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12?\n\x0f\x62ucket_matchers\x18\x03 \x01(\x0b\x32\x1c.xds.type.matcher.v3.MatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x46\n\x0e\x66ilter_enabled\x18\x04 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12G\n\x0f\x66ilter_enforced\x18\x05 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12\x63\n(request_headers_to_add_when_not_enforced\x18\x06 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\x08\xfa\x42\x05\x92\x01\x02\x10\n\"_\n\x16RateLimitQuotaOverride\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x35\n\x0f\x62ucket_matchers\x18\x02 \x01(\x0b\x32\x1c.xds.type.matcher.v3.Matcher\"\xd8\x0e\n\x1cRateLimitQuotaBucketSettings\x12z\n\x11\x62ucket_id_builder\x18\x01 \x01(\x0b\x32_.envoy.extensions.filters.http.rate_limit_quota.v3.RateLimitQuotaBucketSettings.BucketIdBuilder\x12\x46\n\x12reporting_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0f\xfa\x42\x0c\xaa\x01\t\x08\x01*\x05\x10\x80\xc2\xd7/\x12\x84\x01\n\x16\x64\x65ny_response_settings\x18\x03 \x01(\x0b\x32\x64.envoy.extensions.filters.http.rate_limit_quota.v3.RateLimitQuotaBucketSettings.DenyResponseSettings\x12\x84\x01\n\x16no_assignment_behavior\x18\x04 \x01(\x0b\x32\x64.envoy.extensions.filters.http.rate_limit_quota.v3.RateLimitQuotaBucketSettings.NoAssignmentBehavior\x12\x8e\x01\n\x1b\x65xpired_assignment_behavior\x18\x05 \x01(\x0b\x32i.envoy.extensions.filters.http.rate_limit_quota.v3.RateLimitQuotaBucketSettings.ExpiredAssignmentBehavior\x1av\n\x14NoAssignmentBehavior\x12?\n\x13\x66\x61llback_rate_limit\x18\x01 \x01(\x0b\x32 .envoy.type.v3.RateLimitStrategyH\x00\x42\x1d\n\x16no_assignment_behavior\x12\x03\xf8\x42\x01\x1a\x8a\x03\n\x19\x45xpiredAssignmentBehavior\x12P\n#expired_assignment_behavior_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x13\x66\x61llback_rate_limit\x18\x02 \x01(\x0b\x32 .envoy.type.v3.RateLimitStrategyH\x00\x12\x9e\x01\n\x15reuse_last_assignment\x18\x03 \x01(\x0b\x32}.envoy.extensions.filters.http.rate_limit_quota.v3.RateLimitQuotaBucketSettings.ExpiredAssignmentBehavior.ReuseLastAssignmentH\x00\x1a\x15\n\x13ReuseLastAssignmentB\"\n\x1b\x65xpired_assignment_behavior\x12\x03\xf8\x42\x01\x1a\xf3\x01\n\x14\x44\x65nyResponseSettings\x12.\n\x0bhttp_status\x18\x01 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatus\x12.\n\thttp_body\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValue\x12\'\n\x0bgrpc_status\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12R\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\x08\xfa\x42\x05\x92\x01\x02\x10\n\x1a\xd9\x03\n\x0f\x42ucketIdBuilder\x12\x99\x01\n\x11\x62ucket_id_builder\x18\x01 \x03(\x0b\x32t.envoy.extensions.filters.http.rate_limit_quota.v3.RateLimitQuotaBucketSettings.BucketIdBuilder.BucketIdBuilderEntryB\x08\xfa\x42\x05\x9a\x01\x02\x08\x01\x1a\x82\x01\n\x0cValueBuilder\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x42\n\x0c\x63ustom_value\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigH\x00\x42\x16\n\x0fvalue_specifier\x12\x03\xf8\x42\x01\x1a\xa4\x01\n\x14\x42ucketIdBuilderEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12{\n\x05value\x18\x02 \x01(\x0b\x32l.envoy.extensions.filters.http.rate_limit_quota.v3.RateLimitQuotaBucketSettings.BucketIdBuilder.ValueBuilder:\x02\x38\x01\x42\xd5\x01\n?io.envoyproxy.envoy.extensions.filters.http.rate_limit_quota.v3B\x13RateLimitQuotaProtoP\x01Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/rate_limit_quota/v3;rate_limit_quotav3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.rate_limit_quota.v3.rate_limit_quota_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.extensions.filters.http.rate_limit_quota.v3B\023RateLimitQuotaProtoP\001Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/rate_limit_quota/v3;rate_limit_quotav3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _RATELIMITQUOTAFILTERCONFIG.fields_by_name['rlqs_server']._options = None
  _RATELIMITQUOTAFILTERCONFIG.fields_by_name['rlqs_server']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RATELIMITQUOTAFILTERCONFIG.fields_by_name['domain']._options = None
  _RATELIMITQUOTAFILTERCONFIG.fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _RATELIMITQUOTAFILTERCONFIG.fields_by_name['bucket_matchers']._options = None
  _RATELIMITQUOTAFILTERCONFIG.fields_by_name['bucket_matchers']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RATELIMITQUOTAFILTERCONFIG.fields_by_name['request_headers_to_add_when_not_enforced']._options = None
  _RATELIMITQUOTAFILTERCONFIG.fields_by_name['request_headers_to_add_when_not_enforced']._serialized_options = b'\372B\005\222\001\002\020\n'
  _RATELIMITQUOTABUCKETSETTINGS_NOASSIGNMENTBEHAVIOR.oneofs_by_name['no_assignment_behavior']._options = None
  _RATELIMITQUOTABUCKETSETTINGS_NOASSIGNMENTBEHAVIOR.oneofs_by_name['no_assignment_behavior']._serialized_options = b'\370B\001'
  _RATELIMITQUOTABUCKETSETTINGS_EXPIREDASSIGNMENTBEHAVIOR.oneofs_by_name['expired_assignment_behavior']._options = None
  _RATELIMITQUOTABUCKETSETTINGS_EXPIREDASSIGNMENTBEHAVIOR.oneofs_by_name['expired_assignment_behavior']._serialized_options = b'\370B\001'
  _RATELIMITQUOTABUCKETSETTINGS_EXPIREDASSIGNMENTBEHAVIOR.fields_by_name['expired_assignment_behavior_timeout']._options = None
  _RATELIMITQUOTABUCKETSETTINGS_EXPIREDASSIGNMENTBEHAVIOR.fields_by_name['expired_assignment_behavior_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _RATELIMITQUOTABUCKETSETTINGS_DENYRESPONSESETTINGS.fields_by_name['response_headers_to_add']._options = None
  _RATELIMITQUOTABUCKETSETTINGS_DENYRESPONSESETTINGS.fields_by_name['response_headers_to_add']._serialized_options = b'\372B\005\222\001\002\020\n'
  _RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER_VALUEBUILDER.oneofs_by_name['value_specifier']._options = None
  _RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER_VALUEBUILDER.oneofs_by_name['value_specifier']._serialized_options = b'\370B\001'
  _RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER_BUCKETIDBUILDERENTRY._options = None
  _RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER_BUCKETIDBUILDERENTRY._serialized_options = b'8\001'
  _RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER.fields_by_name['bucket_id_builder']._options = None
  _RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER.fields_by_name['bucket_id_builder']._serialized_options = b'\372B\005\232\001\002\010\001'
  _RATELIMITQUOTABUCKETSETTINGS.fields_by_name['reporting_interval']._options = None
  _RATELIMITQUOTABUCKETSETTINGS.fields_by_name['reporting_interval']._serialized_options = b'\372B\014\252\001\t\010\001*\005\020\200\302\327/'
  _globals['_RATELIMITQUOTAFILTERCONFIG']._serialized_start=526
  _globals['_RATELIMITQUOTAFILTERCONFIG']._serialized_end=956
  _globals['_RATELIMITQUOTAOVERRIDE']._serialized_start=958
  _globals['_RATELIMITQUOTAOVERRIDE']._serialized_end=1053
  _globals['_RATELIMITQUOTABUCKETSETTINGS']._serialized_start=1056
  _globals['_RATELIMITQUOTABUCKETSETTINGS']._serialized_end=2936
  _globals['_RATELIMITQUOTABUCKETSETTINGS_NOASSIGNMENTBEHAVIOR']._serialized_start=1699
  _globals['_RATELIMITQUOTABUCKETSETTINGS_NOASSIGNMENTBEHAVIOR']._serialized_end=1817
  _globals['_RATELIMITQUOTABUCKETSETTINGS_EXPIREDASSIGNMENTBEHAVIOR']._serialized_start=1820
  _globals['_RATELIMITQUOTABUCKETSETTINGS_EXPIREDASSIGNMENTBEHAVIOR']._serialized_end=2214
  _globals['_RATELIMITQUOTABUCKETSETTINGS_EXPIREDASSIGNMENTBEHAVIOR_REUSELASTASSIGNMENT']._serialized_start=2157
  _globals['_RATELIMITQUOTABUCKETSETTINGS_EXPIREDASSIGNMENTBEHAVIOR_REUSELASTASSIGNMENT']._serialized_end=2178
  _globals['_RATELIMITQUOTABUCKETSETTINGS_DENYRESPONSESETTINGS']._serialized_start=2217
  _globals['_RATELIMITQUOTABUCKETSETTINGS_DENYRESPONSESETTINGS']._serialized_end=2460
  _globals['_RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER']._serialized_start=2463
  _globals['_RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER']._serialized_end=2936
  _globals['_RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER_VALUEBUILDER']._serialized_start=2639
  _globals['_RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER_VALUEBUILDER']._serialized_end=2769
  _globals['_RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER_BUCKETIDBUILDERENTRY']._serialized_start=2772
  _globals['_RATELIMITQUOTABUCKETSETTINGS_BUCKETIDBUILDER_BUCKETIDBUILDERENTRY']._serialized_end=2936
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/grpc_credential/v3/aws_iam.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-envoy/config/grpc_credential/v3/aws_iam.proto\x12\x1f\x65nvoy.config.grpc_credential.v3\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8f\x01\n\x0c\x41wsIamConfig\x12(\n\x0cservice_name\x18\x01 \x01(\tB\x12\x18\x01\xfa\x42\x04r\x02\x10\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x1b\n\x06region\x18\x02 \x01(\tB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0:8\x9a\xc5\x88\x1e\x33\n1envoy.config.grpc_credential.v2alpha.AwsIamConfigB\xa0\x01\n-io.envoyproxy.envoy.config.grpc_credential.v3B\x0b\x41wsIamProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/config/grpc_credential/v3;grpc_credentialv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.grpc_credential.v3.aws_iam_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-io.envoyproxy.envoy.config.grpc_credential.v3B\013AwsIamProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/config/grpc_credential/v3;grpc_credentialv3\272\200\310\321\006\002\020\002'
  _AWSIAMCONFIG.fields_by_name['service_name']._options = None
  _AWSIAMCONFIG.fields_by_name['service_name']._serialized_options = b'\030\001\372B\004r\002\020\001\222\307\206\330\004\0033.0'
  _AWSIAMCONFIG.fields_by_name['region']._options = None
  _AWSIAMCONFIG.fields_by_name['region']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _AWSIAMCONFIG._options = None
  _AWSIAMCONFIG._serialized_options = b'\232\305\210\0363\n1envoy.config.grpc_credential.v2alpha.AwsIamConfig'
  _globals['_AWSIAMCONFIG']._serialized_start=211
  _globals['_AWSIAMCONFIG']._serialized_end=354
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_json_reverse_transcoder/v3/transcoder.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNenvoy/extensions/filters/http/grpc_json_reverse_transcoder/v3/transcoder.proto\x12=envoy.extensions.filters.http.grpc_json_reverse_transcoder.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf8\x01\n\x19GrpcJsonReverseTranscoder\x12\x17\n\x0f\x64\x65scriptor_path\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65scriptor_binary\x18\x02 \x01(\x0c\x12\x44\n\x15max_request_body_size\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12\x45\n\x16max_response_body_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12\x1a\n\x12\x61pi_version_header\x18\x05 \x01(\tB\xee\x01\nKio.envoyproxy.envoy.extensions.filters.http.grpc_json_reverse_transcoder.v3B\x0fTranscoderProtoP\x01Z\x83\x01github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_json_reverse_transcoder/v3;grpc_json_reverse_transcoderv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.grpc_json_reverse_transcoder.v3.transcoder_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nKio.envoyproxy.envoy.extensions.filters.http.grpc_json_reverse_transcoder.v3B\017TranscoderProtoP\001Z\203\001github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_json_reverse_transcoder/v3;grpc_json_reverse_transcoderv3\272\200\310\321\006\002\020\002'
  _GRPCJSONREVERSETRANSCODER.fields_by_name['max_request_body_size']._options = None
  _GRPCJSONREVERSETRANSCODER.fields_by_name['max_request_body_size']._serialized_options = b'\372B\004*\002 \000'
  _GRPCJSONREVERSETRANSCODER.fields_by_name['max_response_body_size']._options = None
  _GRPCJSONREVERSETRANSCODER.fields_by_name['max_response_body_size']._serialized_options = b'\372B\004*\002 \000'
  _globals['_GRPCJSONREVERSETRANSCODER']._serialized_start=234
  _globals['_GRPCJSONREVERSETRANSCODER']._serialized_end=482
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v3/regex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/type/matcher/v3/regex.proto\x12\x15\x65nvoy.type.matcher.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb4\x02\n\x0cRegexMatcher\x12P\n\ngoogle_re2\x18\x01 \x01(\x0b\x32-.envoy.type.matcher.v3.RegexMatcher.GoogleRE2B\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12\x16\n\x05regex\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x82\x01\n\tGoogleRE2\x12\x43\n\x10max_program_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0:0\x9a\xc5\x88\x1e+\n)envoy.type.matcher.RegexMatcher.GoogleRE2:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.type.matcher.RegexMatcherB\r\n\x0b\x65ngine_type\"\xaf\x01\n\x17RegexMatchAndSubstitute\x12>\n\x07pattern\x18\x01 \x01(\x0b\x32#.envoy.type.matcher.v3.RegexMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12!\n\x0csubstitution\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00:1\x9a\xc5\x88\x1e,\n*envoy.type.matcher.RegexMatchAndSubstituteB\x83\x01\n#io.envoyproxy.envoy.type.matcher.v3B\nRegexProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.v3.regex_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.type.matcher.v3B\nRegexProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\272\200\310\321\006\002\020\002'
  _REGEXMATCHER_GOOGLERE2.fields_by_name['max_program_size']._options = None
  _REGEXMATCHER_GOOGLERE2.fields_by_name['max_program_size']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _REGEXMATCHER_GOOGLERE2._options = None
  _REGEXMATCHER_GOOGLERE2._serialized_options = b'\232\305\210\036+\n)envoy.type.matcher.RegexMatcher.GoogleRE2'
  _REGEXMATCHER.fields_by_name['google_re2']._options = None
  _REGEXMATCHER.fields_by_name['google_re2']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _REGEXMATCHER.fields_by_name['regex']._options = None
  _REGEXMATCHER.fields_by_name['regex']._serialized_options = b'\372B\004r\002\020\001'
  _REGEXMATCHER._options = None
  _REGEXMATCHER._serialized_options = b'\232\305\210\036!\n\037envoy.type.matcher.RegexMatcher'
  _REGEXMATCHANDSUBSTITUTE.fields_by_name['pattern']._options = None
  _REGEXMATCHANDSUBSTITUTE.fields_by_name['pattern']._serialized_options = b'\372B\005\212\001\002\020\001'
  _REGEXMATCHANDSUBSTITUTE.fields_by_name['substitution']._options = None
  _REGEXMATCHANDSUBSTITUTE.fields_by_name['substitution']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _REGEXMATCHANDSUBSTITUTE._options = None
  _REGEXMATCHANDSUBSTITUTE._serialized_options = b'\232\305\210\036,\n*envoy.type.matcher.RegexMatchAndSubstitute'
  _globals['_REGEXMATCHER']._serialized_start=221
  _globals['_REGEXMATCHER']._serialized_end=529
  _globals['_REGEXMATCHER_GOOGLERE2']._serialized_start=344
  _globals['_REGEXMATCHER_GOOGLERE2']._serialized_end=474
  _globals['_REGEXMATCHANDSUBSTITUTE']._serialized_start=532
  _globals['_REGEXMATCHANDSUBSTITUTE']._serialized_end=707
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/socket_cmsg_headers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.envoy/config/core/v3/socket_cmsg_headers.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\"\x83\x01\n\x11SocketCmsgHeaders\x12+\n\x05level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x15\n\rexpected_size\x18\x03 \x01(\rB\x8a\x01\n\"io.envoyproxy.envoy.config.core.v3B\x16SocketCmsgHeadersProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.socket_cmsg_headers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\026SocketCmsgHeadersProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _globals['_SOCKETCMSGHEADERS']._serialized_start=136
  _globals['_SOCKETCMSGHEADERS']._serialized_end=267
# @@protoc_insertion_point(module_scope)
